﻿using System.Windows.Controls;
using Infragistics.Olap.FlatData;

namespace CustomAggregatorSample
{
    public partial class MainPage : UserControl
    {
        private void SetProductsCubeMetadata(FlatDataSource flatDataSource)
        {
            /* allows you to create a virtual dimensions and measures
             * look at userNameMetadata below. 
             * it's not connected with any source property but it
             * requires to have a at least one hierachy descriptor*/
            flatDataSource.DimensionsGenerationMode = DimensionsGenerationMode.Mixed;

            CubeMetadata cubeMetadata =
                new CubeMetadata
                {
                    DisplayName = "Products",
                    DataTypeFullName = typeof(ProductData).FullName
                };

            flatDataSource.CubesSettings.Add(cubeMetadata);

            // create measure over Cost property
            DimensionMetadata costMetadata =
                new DimensionMetadata
                {
                    SourcePropertyName = "Cost",
                    DimensionType = DimensionType.Measure
                };

            // create only over SalesAmount property
            DimensionMetadata salesAmountMetadata =
                new DimensionMetadata
                {
                    SourcePropertyName = "SalesAmount",
                    DisplayName = "Sales Amount",
                    DimensionType = DimensionType.Measure
                };

            // create only over GrossProfit property
            DimensionMetadata grossProfitMetadata =
                new DimensionMetadata
                {
                    SourcePropertyName = "GrossProfit",
                    DisplayName = "Gross Profit",
                    DimensionType = DimensionType.Measure
                };

            // create measure for "Gross Profit %
            // custom aggregator
            DimensionMetadata grossProfitPercMetadata =
                new DimensionMetadata
                {
                    SourcePropertyName = "GrossProfit",
                    DisplayName = "Gross Profit %",
                    DisplayFormat = "{0:00.##%}",
                    DimensionType = DimensionType.Measure,
                    Aggregator = new GrossProfitAggregator(flatDataSource)
                };

            cubeMetadata.DimensionSettings.Add(costMetadata);
            cubeMetadata.DimensionSettings.Add(salesAmountMetadata);
            cubeMetadata.DimensionSettings.Add(grossProfitMetadata);
            cubeMetadata.DimensionSettings.Add(grossProfitPercMetadata);

            // create a complex hierarchy over Location            
            HierarchyDescriptor<ProductData> productsHierarchyDescriptor =
                new HierarchyDescriptor<ProductData>(pd => pd.ProductName) { HierarchyName = "Products" };
            productsHierarchyDescriptor.AddLevel("All", "All");
            productsHierarchyDescriptor.AddLevel(pd => pd.ProductName, "Products");

            flatDataSource.AddHierarchyDescriptor(productsHierarchyDescriptor);
        }
    }
}
